MnoCheckoutRequest class

MnoCheckoutRequest

Inheritance

Constructors

MnoCheckoutRequest({required String accountNumber, Map<String, dynamic>? additionalProperties, required String amount, required String currency, required String externalId, required MnoProvider provider})
MnoCheckoutRequest.fromMap(Map<String, dynamic> map)
factory

Properties

accountNumber → String
Account number/MSISDN that consumer will provide. The amount will be deducted from this account.
final
additionalProperties → Map<String, dynamic>?
Additional data that calling application can provide. This is optional.
final
amount → String
Amount to be deducted from the consumer account.
final
currency → String
Currency code of the amount. Current support values are only (TZS)
final
externalId → String
Belongs to the calling application
final
hashCode → int
The hash code for this object.
no setterinherited
provider → MnoProvider
Mobile network provider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the model to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited